@@ -1,31 +1,32 @@
+import os
 import sys
 from PyQt5.QtGui import QIcon
 
 from matplotlib import pyplot as plt
 
-from .plot import PlotWindow
-from .prep_func_dialog_classes import *
-
-from .save_data import get_valid_save_name, write_fif
-from .load_data import get_open_file_name, read_raw
-
-from .filter import filter_func
-from .resample import resample_func, resample_data_and_events_func
-from .notch import n_filter_func
-from .reference import set_reference_func
-from .baseline import baseline_func
-from .epochs import epoch_func, drop_bad_epochs_func
-from .bad_chs import mark_bad_chs, interp_bad_chs
-from .check_channel_types import check_for_ch_type
-from .ica import generate_ica, fit_ica_no_autoreject, fit_ica_with_autoreject, reject_eog_eeg_comps, apply_ica
-from .pipeline_dicts import get_preset_pipeline
-from .msgbxs import alert_msg
+from plot import PlotWindow
+from prep_func_dialog_classes import *
+from save_data import get_valid_save_name, write_fif
+from load_data import get_open_file_name, read_raw
+from filter import filter_func
+from resample import resample_func, resample_data_and_events_func
+from notch import n_filter_func
+from reference import set_reference_func
+from baseline import baseline_func
+from epochs import epoch_func, drop_bad_epochs_func
+from bad_chs import mark_bad_chs, interp_bad_chs
+from check_channel_types import check_for_ch_type
+from ica import generate_ica, fit_ica_no_autoreject, fit_ica_with_autoreject, reject_eog_eeg_comps, apply_ica
+from pipeline_dicts import get_preset_pipeline
+from msgbxs import alert_msg
 
 class MainWindow(QMainWindow):
 
-    def __init__(self):
+    def __init__(self, app):
         super(MainWindow, self).__init__()
 
+        self.app = app
+
         self.pipeline = [["", {}] for i in range(10)] # initialise
 
         self.options_windows = [QWidget for i in range(10)]
@@ -106,6 +107,9 @@ class MainWindow(QMainWindow):
         openAct = QAction(QIcon('open.png'), '&Open...', self)
         openAct.triggered.connect(self.load_in_data)
 
+        load_example_dataAct = QAction("&Download Example Data", self)
+        load_example_dataAct.triggered.connect(self.load_example_data)
+
         plotAct = QAction('&Plot', self)
         plotAct.triggered.connect(self.plot_data)
 
@@ -128,6 +132,7 @@ class MainWindow(QMainWindow):
         menubar = self.menuBar()
         fileMenu = menubar.addMenu('&File')
         fileMenu.addAction(openAct)
+        fileMenu.addAction(load_example_dataAct)
         plotMenu = menubar.addMenu("&Plot")
         plotMenu.addAction(plotAct)
         pipelineMenu = menubar.addMenu("&Load Pipeline")
@@ -162,7 +167,6 @@ class MainWindow(QMainWindow):
                 new_size = self.fname_lbl.sizeHint()
                 self.fname_lbl.setMinimumSize(new_size)
 
-
                 # enable radio buttons for erp  vs resting data
                 self.erp_r_btn.setDisabled(False)
                 self.resting_r_btn.setDisabled(False)
@@ -173,6 +177,35 @@ class MainWindow(QMainWindow):
                                                    "only and that file type is supported")
                 return
 
+    def load_example_data(self):
+        options = QFileDialog.Options()
+        options |= QFileDialog.DontUseNativeDialog
+        dir_name = QFileDialog.getExistingDirectory(self, "Save example data in...", "", options=options)
+
+        if dir_name != "":
+            try:
+                sample_data_folder = mne.datasets.sample.data_path(dir_name)
+                sample_data_raw_file = os.path.join(sample_data_folder, 'MEG', 'sample',
+                                                    'sample_audvis_raw.fif')
+                fileName = sample_data_raw_file
+
+                # load data
+                self.data = read_raw(fileName)
+                # set label to reflect opened file
+                fname = fileName.split("/")[-1]
+                self.fname_lbl.setText("Data File: " + fname)
+                # resize the label widget dynamically to ensure it is large enough for the string
+                new_size = self.fname_lbl.sizeHint()
+                self.fname_lbl.setMinimumSize(new_size)
+
+                # enable radio buttons for erp  vs resting data
+                self.erp_r_btn.setDisabled(False)
+                self.resting_r_btn.setDisabled(False)
+
+            except ValueError:
+                QMessageBox.warning(self, "Error", "Problem reading file in to MNE. Check file type is supported")
+                return
+
     def get_stim_ch_and_events(self, data):
 
         data.stim_channel = self.stim_chan_select.currentText()
@@ -302,7 +335,7 @@ class MainWindow(QMainWindow):
         # if valid save name, do preprocessing
 
         self.statusBar().showMessage('Running pipeline...')
-        app.processEvents() # use this to update the GUI while the function is running. Aware not a good solution and
+        self.app.processEvents() # use this to update the GUI while the function is running. Aware not a good solution and
         # best practice would likely be to run the function in a worker thread, but implementing as a quick fix to get the
         # functionality out for testing
 
@@ -321,7 +354,7 @@ class MainWindow(QMainWindow):
                 process_params = self.get_pipeline_process_params(i)
                 if process_name == "filter":
                     self.statusBar().showMessage('Applying filter...')
-                    app.processEvents()
+                    self.app.processEvents()
 
                     #data_filtered = data.copy().filter(l_freq = process_params["l_freq"], h_freq = process_params["h_freq"], method=process_params["method"])
                     data_filtered = filter_func(data, process_params)
@@ -332,7 +365,7 @@ class MainWindow(QMainWindow):
                     print()
                 elif process_name == "resample":
                     self.statusBar().showMessage('Resampling...')
-                    app.processEvents()
+                    self.app.processEvents()
 
                     #data_resampled = data.copy().resample(sfreq=process_params["sfreq"])
                     if len(data.events) == 0: # no events/stim channel
@@ -347,7 +380,7 @@ class MainWindow(QMainWindow):
                     print()
                 elif process_name == "line_noise":
                     self.statusBar().showMessage('Removing line noise...')
-                    app.processEvents()
+                    self.app.processEvents()
 
                     if isinstance(data, mne.io.BaseRaw):
                     #data_notched = data.copy().notch_filter(freqs=process_params["freqs"]) # works with/without comma eg both freqs = (50) & (50,) are fine
@@ -363,7 +396,7 @@ class MainWindow(QMainWindow):
                         return
                 elif process_name == "set_reference":
                     self.statusBar().showMessage('Setting EEG reference...')
-                    app.processEvents()
+                    self.app.processEvents()
 
                     # check that data actually has EEG channels
                     if check_for_ch_type(data, ["EEG"]):
@@ -381,11 +414,11 @@ class MainWindow(QMainWindow):
                         return
                 elif process_name == "channels":
                     self.statusBar().showMessage('Marking bad channels...')
-                    app.processEvents()
+                    self.app.processEvents()
                     data_bad_chs = mark_bad_chs(data, process_params)
                     if process_params["interpolate"]:
                         self.statusBar().showMessage('Interpolating bad channels...')
-                        app.processEvents()
+                        self.app.processEvents()
                         #data.plot(block=True) # plots to check that the channels (in raw data) have been interpolated
                         data_bads_interp = interp_bad_chs(data_bad_chs)
                         #data_bads_interp.plot(block=True) # plots to check that the channels have been interpolated
@@ -404,14 +437,14 @@ class MainWindow(QMainWindow):
                         #try:
                         if process_params["autoreject"]:
                             self.statusBar().showMessage('Epoching (and dropping bad epochs)...')
-                            app.processEvents()
+                            self.app.processEvents()
                             epochs_drop_bad = drop_bad_epochs_func(data, process_params)
                             # processes_list.append(epochs_drop_bad)
                             data = epochs_drop_bad  # overwrite
                             del epochs_drop_bad  # delete to free up RAM
                         else: # if no autoreject
                             self.statusBar().showMessage('Epoching...')
-                            app.processEvents()
+                            self.app.processEvents()
                             epochs = epoch_func(data, process_params)
                             #processes_list.append(epochs)
                             data = epochs  # overwrite
@@ -424,7 +457,7 @@ class MainWindow(QMainWindow):
                         return
                 elif process_name == "baseline":
                     self.statusBar().showMessage('Applying baseline...')
-                    app.processEvents()
+                    self.app.processEvents()
                     try:
                         # epochs_baselined = data.copy().apply_baseline(process_params["interval"])
                         epochs_baselined = baseline_func(data, process_params)
@@ -443,17 +476,17 @@ class MainWindow(QMainWindow):
                     print()
                 elif process_name == "ICA":
                     self.statusBar().showMessage('Performing ICA (may take a while)...')
-                    app.processEvents()
+                    self.app.processEvents()
                     if isinstance(data, mne.io.BaseRaw) or isinstance(data, mne.BaseEpochs):
 
                         # 1) generate ICA
                         self.statusBar().showMessage('Generating ICA (may take a while)...')
-                        app.processEvents()
+                        self.app.processEvents()
                         self.ica = generate_ica(data, process_params, self)
 
                         # 2) fit ICA
                         self.statusBar().showMessage('Fitting ICA (may take a while)...')
-                        app.processEvents()
+                        self.app.processEvents()
                         if process_params["autoreject"]:
                             fit_ica_with_autoreject(self.ica, data)
                         else:
@@ -461,7 +494,7 @@ class MainWindow(QMainWindow):
 
                         # 3) exclude components
                         self.statusBar().showMessage('Excluding components (may take a while)...')
-                        app.processEvents()
+                        self.app.processEvents()
                         if process_params["rejection_method"] == "ecg_eog":
                             # check that data actually has EOG and ECG/MEG channels
                             if check_for_ch_type(data, ["ECG", "EOG"]) \
@@ -515,7 +548,7 @@ class MainWindow(QMainWindow):
 
                         # 4) apply ICA
                         self.statusBar().showMessage('Applying ICA...')
-                        app.processEvents()
+                        self.app.processEvents()
                         reconst_data = apply_ica(self.ica, data)
 
 
