@@ -5,7 +5,7 @@ from PyQt5.QtCore import Qt
 
 from mne.io.pick import channel_type, get_channel_type_constants
 
-from .msgbxs import alert_msg
+from msgbxs import alert_msg
 
 
 def options_dialog_cancel(dialog_window, main_window):
